#
# spec file for package ghc-typst
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name typst
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5
Release:        150500.11.3.1
Summary:        Parsing and evaluating typst syntax
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cassava-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-digits-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-ordered-containers-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-toml-parser-devel
BuildRequires:  ghc-typst-symbols-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-conduit-devel
BuildRequires:  ghc-yaml-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-pretty-show-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
%endif

%description
A library for parsing and evaluating typst syntax. Typst (<https://typst.app>)
is a document layout and formatting language. This library targets typst 0.10
and currently offers only partial support.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%changelog
* Sat Dec 16 2023 psimons@suse.com
- Update typst to version 0.5.
  [#]# 0.5
  * Support "as" keyword in imports (#21).
    [API change] In Typst.Syntax, the Imports type now contains
    fields for an optional "as" identifier.
  * Support version type (#21).
    [API change] Add VVersion constructor to Val, TVersion to ValType.
    Support the `version` constructor function and the `at` method (#21).
  * Parser: Ensure that `set` rule doesn't pick up `if` on next line (#23).
  * Parser: Allow multiline strings (#20).
  * Allow function applications in dictionary key construction (#19).
    [API change]:  in Typst.Syntax, the Dict constructor for Expr
    now takes type `[Spreadable (Expr, Expr)]` instead of
    `[Spreadable (Identifier, Expr)]`. This is because the key
    identifiers sometimes are not known at parse time and must
    be computed in Evaluate.
  [#]# 0.4
  * `evaluateTypst` now returns a single Content instead of a sequence
    (breaking API change). The Content is a "document" element that wraps
    the other contents. (This is added automatically in typst:
    https://typst.app/docs/reference/model/document/#parameters-title.)
  * Improve math parser.
  * Add `sys` module and `sys.version`.
  * Math: add `sech` and `csch` operators, `math.mid`.
  * `math.op` is no longer limited to string argument.
  * Remove automatic matching for `|..|` in math (typst 0.8 breaking change).
  * Fix `in` so it works with a type.
  * `repr` label with angle brackets.
  * `cite` now just takes one positional element, a label
    instead of strings (typst 0.9 breaing change).
  * Add `quote` element.
  * Add first-class types. `type()` function now returns a
    ValType instead of a string. Allow ValTypes to == strings
    for compatibility, as in typst.
  * `highlight` element for text.
  * Allow array `zip` method to take any number of arguments.
  * Add `calc.tau`.
  * Add array `intersperse` method.
  * Add string `rev` method.
  * Fix search path for typst packages, from
    `cache/typst/packages/preview/packagename-major.minor.patch` to
    `cache/typst/packages/preview/packagename-major/minor.patch` (#18).
  * Add support of 'wide' spacing character.
  * Fix precedence for numerical attachments (#17).
    Typst makes a subtle distinction between `$a_1(x)$`, in which
    the `_` groups more tightly than the `(..)`, and $`a_f(x)$`,
    in which the `(..)` groups more tightly than the `_`.
    This patch implements the distinction.  This fixes conversion of,
    e.g., `$n(a)^(b)$`.
  * Use typst-symbols 0.1.5.
* Fri Oct 27 2023 psimons@suse.com
- Add typst at version 0.3.2.1.
